/**
 * Copyright 2010 Västra Götalandsregionen
 *
 *   This library is free software; you can redistribute it and/or modify
 *   it under the terms of version 2.1 of the GNU Lesser General Public
 *   License as published by the Free Software Foundation.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the
 *   Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 *   Boston, MA 02111-1307  USA
 */

package se.vgregion.security.sign;

import java.beans.PropertyEditorSupport;

import se.vgregion.dao.domain.patterns.repository.Repository;
import se.vgregion.domain.security.pkiclient.ELegType;
import se.vgregion.web.exceptions.IllegalWebArgumentException;

/**
 * A {@link java.beans.PropertyEditor} which converts a {@link String} into a {@link ELegType}.
 * 
 * @author Anders Asplund - <a href="http://www.callistaenterprise.se">Callista Enterprise</a>
 */
public class ELegTypeEditor extends PropertyEditorSupport {
    private Repository<ELegType, String> eLegTypes;

    /**
     * Constructs an {@link ELegTypeEditor}.
     * 
     * @param eLegTypes
     *            repository containing all types of e-legitimation.
     */
    public ELegTypeEditor(Repository<ELegType, String> eLegTypes) {
        this.eLegTypes = eLegTypes;
    }

    /*
     * (non-Javadoc)
     * 
     * @see java.beans.PropertyEditorSupport#setAsText(java.lang.String)
     */
    @Override
    public void setAsText(String clientType) {
        ELegType eLegType = eLegTypes.find(clientType);
        if (eLegType == null) {
            throw new IllegalWebArgumentException();
        }
        setValue(eLegType);
    }
}
